# eyantra-autoeval

## Usage

> NOTE: Check [#3][i3] for generating result from the evaluator.

- For `Sentinel Drone` theme

```sh
eyantra-autoeval evaluate --year 2022 --theme SD --task 0
```

- For `Luminosity Drone` theme

```sh
eyantra-autoeval evaluate --year 2023 --theme LD --task 0
```

- For `AstroTinker Bot` theme

```sh
eyantra-autoeval evaluate --year 2023 --theme AB --task 0
```

- For `Cosmo Logistic` theme

```sh
eyantra-autoeval evaluate --year 2023 --theme CL --task 0
```

[i3]: https://github.com/eYantra-Robotics-Competition/eyantra-autoeval/issues/3
